gb: Use the NS-VCI to find an existing NS-VC

Currently when a NS-RESET is recevied over a link that has not yet
been associated with a NS-VC, the NSEI is used to find an existing
NS-VC. If one is found, the reset procedure is initiated.

This behaviour is not conformant with 3GPP TS 08.16 (see chapter
4.2.3) which allows to use several NS-VC between two endpoints in
parallel.

The patch changes the implementation to use the NSVCI instead
of the NSEI to search for an existing NS-VC object.

Ticket: OW#874
Sponsored-by: On-Waves ehf
diff --git a/tests/gb/gprs_ns_test.ok b/tests/gb/gprs_ns_test.ok
index 049b5e6..578b905 100644
--- a/tests/gb/gprs_ns_test.ok
+++ b/tests/gb/gprs_ns_test.ok
@@ -68,6 +68,7 @@
 
 Current NS-VCIs:
     VCI 0x3344, NSEI 0x1122, peer 0x01020304:3333
+    VCI 0x1122, NSEI 0x1122, peer 0x01020304:2222
 
 --- Peer port changes, RESET, NSEI changes ---
 
@@ -83,8 +84,8 @@
 result (RESET) = 9
 
 Current NS-VCIs:
-    VCI 0x1122, NSEI 0x3344, peer 0x01020304:4444
     VCI 0x3344, NSEI 0x1122, peer 0x01020304:3333
+    VCI 0x1122, NSEI 0x3344, peer 0x01020304:4444
 
 --- Peer port 3333, RESET, VCI is changed back ---
 
@@ -100,8 +101,8 @@
 result (RESET) = 9
 
 Current NS-VCIs:
-    VCI 0x1122, NSEI 0x3344, peer 0x01020304:4444
     VCI 0x1122, NSEI 0x1122, peer 0x01020304:3333
+    VCI 0x1122, NSEI 0x3344, peer 0x01020304:4444
 
 --- Peer port 4444, RESET, NSEI is changed back ---
 
@@ -117,8 +118,8 @@
 result (RESET) = 9
 
 Current NS-VCIs:
-    VCI 0x1122, NSEI 0x1122, peer 0x01020304:4444
     VCI 0x1122, NSEI 0x1122, peer 0x01020304:3333
+    VCI 0x1122, NSEI 0x1122, peer 0x01020304:4444
 
 ===== NS protocol test END
diff --git a/src/gb/gprs_ns.c b/src/gb/gprs_ns.c
index 0fed43c..b5f91c4 100644
--- a/src/gb/gprs_ns.c
+++ b/src/gb/gprs_ns.c
@@ -823,7 +823,7 @@
 	struct gprs_nsvc *existing_nsvc;
 
 	struct tlv_parsed tp;
-	uint16_t nsei;
+	uint16_t nsvci;
 
 	int rc;
 
@@ -868,10 +868,10 @@
 				  msg);
 		return -EINVAL;
 	}
-	nsei = ntohs(*(uint16_t *) TLVP_VAL(&tp, NS_IE_NSEI));
-	/* Check if we already know this NSEI, the remote end might
+	nsvci = ntohs(*(uint16_t *) TLVP_VAL(&tp, NS_IE_VCI));
+	/* Check if we already know this NSVCI, the remote end might
 	 * simply have changed addresses, or it is a SGSN */
-	existing_nsvc = gprs_nsvc_by_nsei(nsi, nsei);
+	existing_nsvc = gprs_nsvc_by_nsvci(nsi, nsvci);
 	if (!existing_nsvc) {
 		*new_nsvc = gprs_nsvc_create(nsi, 0xffff);
 		log_set_context(GPRS_CTX_NSVC, *new_nsvc);